package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaRaise;
import com.huiju.estateagents.service.ITaRaiseService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 认筹表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-26
 */
@RestController
@RequestMapping("/api")
public class TaRaiseController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRaiseController.class);

    @Autowired
    public ITaRaiseService iTaRaiseService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taRaise",method= RequestMethod.GET)
    public ResponseBean taRaiseList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                    @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaRaise> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaRaise> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaRaise> result = iTaRaiseService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taRaise 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taRaise",method= RequestMethod.POST)
    public ResponseBean taRaiseAdd(@RequestBody TaRaise taRaise){
        ResponseBean responseBean = new ResponseBean();
        try {
            // 参数校验
            Integer raisePrice = taRaise.getRaisePrice();
            if(raisePrice != null && raisePrice > CommConstant.MAX_RAISE_PRICE){
                responseBean.addError("认筹金额最高50000");
                return responseBean;
            }

            if (iTaRaiseService.save(taRaise)){
                responseBean.addSuccess(taRaise);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taRaise/{id}", method= RequestMethod.DELETE)
    public ResponseBean taRaiseDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaRaiseService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taRaise 实体对象
     * @return
     */
    @RequestMapping(value="/taRaise/{id}",method= RequestMethod.PUT)
    public ResponseBean taRaiseUpdate(@PathVariable Integer id,
                                        @RequestBody TaRaise taRaise){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaRaiseService.updateById(taRaise)){
                responseBean.addSuccess(taRaise);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taRaise/{id}",method= RequestMethod.GET)
    public ResponseBean taRaiseGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaRaiseService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
